4.6. oncilla.sliceReStructuredText — Oncilla 0.1.0 documentation

# 4.6. oncilla.sliceReStructuredText

sliceReStructuredText.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Slices given reStructuredText file.

Others:

## 4.6.1. Module Attributes

`oncilla.sliceReStructuredText.` `LOGGER`

`oncilla.sliceReStructuredText.` `OUTPUT_FILES_EXTENSION`

`oncilla.sliceReStructuredText.` `SLICE_ATTRIBUTE_INDENT`

`oncilla.sliceReStructuredText.` `CONTENT_DELETION`

`oncilla.sliceReStructuredText.` `STATEMENT_SUBSTITUTE`

## 4.6.2. Functions

`oncilla.sliceReStructuredText.` `sliceReStructuredText`(input, output)

  Slices given reStructuredText file.

  Parameters: | input (unicode) – ReStructuredText file to slice. output (unicode) – Directory to output sliced reStructuredText files.
  Returns: | Definition success.
  Return type: | bool

`oncilla.sliceReStructuredText.` `getCommandLineArguments`()

  Retrieves command line arguments.

  Returns: | Namespace.
  Return type: | Namespace

`oncilla.sliceReStructuredText.` `main`()

  Starts the Application.

  Returns: | Definition success.
  Return type: | bool